@@ -1,6 +1,6 @@
 # frozen_string_literal: true
 
-require "byebug/command"
+require_relative "../command"
 
 module Byebug
   #
@@ -16,12 +16,12 @@ module Byebug
 
     def self.description
       <<-DESCRIPTION
-        q[uit] [!|unconditionally]
+        q[uit][!| unconditionally]
 
         #{short_description}
 
-        Normally we prompt before exiting. However if the parameter
-        "unconditionally" is given or command is suffixed with !, we exit
+        Normally we prompt before exiting. However, if the parameter
+        "unconditionally" is given or command is suffixed with "!", we exit
         without asking further questions.
       DESCRIPTION
     end
